# Usage
See [tests/](https://gitlab.com/hukudo/lib/-/tree/main/tests) and
[docs/](https://gitlab.com/hukudo/lib/-/tree/main/1-docs).


# Installation
```
pip install hukudo
```

🔥DRAFT🔥 For Gitlab Tools
```
pip install hukudo[gitlab]
```


# Development
See [1-docs/development.md]
